==> owncloud-8.0.8.tar.bz2: owncloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamientu non disponible",
    "Storage invalid" : "Almacenamientu inválidu",
    "Unknown error" : "Fallu desconocíu",
    "Could not move %s - File with this name already exists" : "Nun pudo movese %s - Yá existe un ficheru con esi nome.",
    "Could not move %s" : "Nun pudo movese %s",
    "Permission denied" : "Permisu denegáu",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "\"%s\" is an invalid file name." : "\"%s\" ye un nome de ficheru inválidu.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome inválidu, los caráuteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" nun tán permitíos.",
    "The target folder has been moved or deleted." : "La carpeta oxetivu movióse o desanicióse.",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nome %s yá ta n'usu na carpeta %s. Por favor, escueyi un nome diferente.",
    "Not a valid source" : "Nun ye una fonte válida",
    "Server is not allowed to open URLs, please check the server configuration" : "Nun se-y permite al sirvidor abrir URLs, por favor comprueba la configuración del sirvidor",
    "The file exceeds your quota by %s" : "El ficheru perpasa la cuota por %s",
    "Error while downloading %s to %s" : "Fallu cuando se descargaba %s a %s",
    "Error when creating the file" : "Fallu cuando se creaba'l ficheru",
    "Folder name cannot be empty." : "El nome la carpeta nun pue tar baleru.",
    "Error when creating the folder" : "Fallu cuando se creaba la carpeta",
    "Unable to set upload directory." : "Nun pue afitase la carpeta de xubida.",
    "Invalid Token" : "Token inválidu",
    "No file was uploaded. Unknown error" : "Nun se xubió dengún ficheru. Fallu desconocíu",
    "There is no error, the file uploaded with success" : "Nun hai dengún fallu, el ficheru xubióse ensin problemes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El ficheru xubíu perpasa la direutiva \"upload_max_filesize\" del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "The uploaded file was only partially uploaded" : "El ficheru xubióse de mou parcial",
    "No file was uploaded" : "Nun se xubió dengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Failed to write to disk" : "Fallu al escribir al discu",
    "Not enough storage available" : "Nun hai abondu espaciu disponible",
    "Upload failed. Could not find uploaded file" : "Xubida fallida.  Nun pudo atopase'l ficheru xubíu.",
    "Upload failed. Could not get file info." : "Falló la xubida.  Nun se pudo obtener la información del ficheru.",
    "Invalid directory." : "Direutoriu non válidu.",
    "Files" : "Ficheros",
    "All files" : "Tolos ficheros",
    "Favorites" : "Favoritos",
    "Home" : "Casa",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamañu de ficheru total {size1} perpasa la llende de xuba {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Upload cancelled." : "Xuba encaboxada.",
    "Could not get result from server." : "Nun pudo obtenese'l resultáu del sirvidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La xuba del ficheru ta en progresu. Si dexes agora la páxina, va encaboxase la xuba.",
    "URL cannot be empty" : "La URL nun pue tar balera",
    "{new_name} already exists" : "{new_name} yá existe",
    "Could not create file" : "Nun pudo crease'l ficheru",
    "Could not create folder" : "Nun pudo crease la carpeta",
    "Error fetching URL" : "Fallu obteniendo URL",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Disconnect storage" : "Desconeutar almacenamientu",
    "Unshare" : "Dexar de compartir",
    "Download" : "Descargar",
    "Pending" : "Pendiente",
    "Error moving file." : "Fallu moviendo'l ficheru.",
    "Error moving file" : "Fallu moviendo'l ficheru",
    "Error" : "Fallu",
    "Could not rename file" : "Nun pudo renomase'l ficheru",
    "Error deleting file." : "Fallu desaniciando'l ficheru.",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "L'aplicación Encryption ta habilitada pero les tos claves nun s'aniciaron, por favor zarra sesión y aníciala de nueves",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Clave privada non válida pa Encryption. Por favor, anueva la to contraseña de clave nos tos axustes personales pa recuperar l'accesu a los tos ficheros cifraos.",
    "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files." : "Deshabilitose'l cifráu pero los tos ficheros tovía tán cifraos.  Por favor, vete a los axustes personales pa descrifrar los tos ficheros.",
    "_matches '{filter}'_::_match '{filter}'_" : ["",""],
    "{dirs} and {files}" : "{dirs} y {files}",
    "Favorite" : "Favoritu",
    "%s could not be renamed as it has been deleted" : "%s nun pue renomase dempués de desaniciase",
    "%s could not be renamed" : "Nun se puede renomar %s ",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "File handling" : "Alministración de ficheros",
    "Maximum upload size" : "Tamañu máximu de xubida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Axustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\">p'acceder a los ficheros a traviés de WebDAV</a>",
    "New" : "Nuevu",
    "New text file" : "Ficheru de testu nuevu",
    "Text file" : "Ficheru de testu",
    "New folder" : "Nueva carpeta",
    "Folder" : "Carpeta",
    "From link" : "Dende enllaz",
    "Upload" : "Xubir",
    "Cancel upload" : "Encaboxar xuba",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "Files are being scanned, please wait." : "Tan escaniándose los ficheros, espera por favor.",
    "Currently scanning" : "Anguaño escaneando"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.5.tar.bz2: owncloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamientu non disponible",
    "Storage invalid" : "Almacenamientu inválidu",
    "Unknown error" : "Fallu desconocíu",
    "Could not move %s - File with this name already exists" : "Nun pudo movese %s - Yá existe un ficheru con esi nome.",
    "Could not move %s" : "Nun pudo movese %s",
    "Permission denied" : "Permisu denegáu",
    "The target folder has been moved or deleted." : "La carpeta oxetivu movióse o desanicióse.",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nome %s yá ta n'usu na carpeta %s. Por favor, escueyi un nome diferente.",
    "Error when creating the file" : "Fallu cuando se creaba'l ficheru",
    "Error when creating the folder" : "Fallu cuando se creaba la carpeta",
    "Unable to set upload directory." : "Nun pue afitase la carpeta de xubida.",
    "Invalid Token" : "Token inválidu",
    "No file was uploaded. Unknown error" : "Nun se xubió dengún ficheru. Fallu desconocíu",
    "There is no error, the file uploaded with success" : "Nun hai dengún fallu, el ficheru xubióse ensin problemes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El ficheru xubíu perpasa la direutiva \"upload_max_filesize\" del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "The uploaded file was only partially uploaded" : "El ficheru xubióse de mou parcial",
    "No file was uploaded" : "Nun se xubió dengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Failed to write to disk" : "Fallu al escribir al discu",
    "Not enough storage available" : "Nun hai abondu espaciu disponible",
    "Upload failed. Could not find uploaded file" : "Xubida fallida.  Nun pudo atopase'l ficheru xubíu.",
    "Upload failed. Could not get file info." : "Falló la xubida.  Nun se pudo obtener la información del ficheru.",
    "Invalid directory." : "Direutoriu non válidu.",
    "Files" : "Ficheros",
    "All files" : "Tolos ficheros",
    "Favorites" : "Favoritos",
    "Home" : "Casa",
    "Close" : "Zarrar",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamañu de ficheru total {size1} perpasa la llende de xuba {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Upload cancelled." : "Xuba encaboxada.",
    "Could not get result from server." : "Nun pudo obtenese'l resultáu del sirvidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La xuba del ficheru ta en progresu. Si dexes agora la páxina, va encaboxase la xuba.",
    "Actions" : "Aiciones",
    "Download" : "Descargar",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Details" : "Detalles",
    "Select" : "Esbillar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "Imposible determinar la fecha",
    "This operation is forbidden" : "La operación ta prohibida",
    "Error moving file." : "Fallu moviendo'l ficheru.",
    "Error moving file" : "Fallu moviendo'l ficheru",
    "Error" : "Fallu",
    "{new_name} already exists" : "{new_name} yá existe",
    "Could not rename file" : "Nun pudo renomase'l ficheru",
    "Could not create file" : "Nun pudo crease'l ficheru",
    "Could not create folder" : "Nun pudo crease la carpeta",
    "Error deleting file." : "Fallu desaniciando'l ficheru.",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "New" : "Nuevu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "Favorite" : "Favoritu",
    "Upload" : "Xubir",
    "Text file" : "Ficheru de testu",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
    "A file or folder has been <strong>changed</strong>" : "<strong>Camudóse</strong> un ficheru o carpeta",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta",
    "You created %1$s" : "Creasti %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "%1$s was created in a public folder" : "Creóse %1$s nuna carpeta pública",
    "You changed %1$s" : "Modificasti %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Desaniciasti %1$s",
    "%2$s deleted %1$s" : "%2$s desanició %1$s",
    "You restored %1$s" : "Recuperóse %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "%s could not be renamed as it has been deleted" : "%s nun pue renomase dempués de desaniciase",
    "%s could not be renamed" : "Nun se puede renomar %s ",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "File handling" : "Alministración de ficheros",
    "Maximum upload size" : "Tamañu máximu de xubida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Axustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\">p'acceder a los ficheros a traviés de WebDAV</a>",
    "Cancel upload" : "Encaboxar xuba",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "Files are being scanned, please wait." : "Tan escaniándose los ficheros, espera por favor.",
    "Currently scanning" : "Anguaño escaneando"
},
"nplurals=2; plural=(n != 1);");
